
import React from 'react';

interface LogoProps {
  size?: number;
  className?: string;
  showText?: boolean;
}

const Logo = ({ size = 40, className = "", showText = true }: LogoProps) => {
  const iconSize = size;
  const textHeight = size * 0.6;
  
  return (
    <div className={`flex items-center ${className}`}>
      {/* Modern 3D Logo Icon */}
      <div style={{ width: iconSize, height: iconSize }}>
        <svg
          width={iconSize}
          height={iconSize}
          viewBox="0 0 100 100"
          fill="none"
          xmlns="http://www.w3.org/2000/svg"
        >
          {/* Gradient definitions */}
          <defs>
            <linearGradient id="logoGradient" x1="0%" y1="0%" x2="100%" y2="100%">
              <stop offset="0%" stopColor="#10b981" />
              <stop offset="100%" stopColor="#059669" />
            </linearGradient>
            <linearGradient id="shadowGradient" x1="0%" y1="0%" x2="100%" y2="100%">
              <stop offset="0%" stopColor="#10b981" stopOpacity="0.4" />
              <stop offset="100%" stopColor="#059669" stopOpacity="0.1" />
            </linearGradient>
            <filter id="glow">
              <feGaussianBlur stdDeviation="3" result="coloredBlur"/>
              <feMerge> 
                <feMergeNode in="coloredBlur"/>
                <feMergeNode in="SourceGraphic"/>
              </feMerge>
            </filter>
          </defs>
          
          {/* Outer glow/shadow with 3D effect */}
          <rect
            x="2"
            y="6"
            width="92"
            height="92"
            rx="20"
            ry="20"
            fill="url(#shadowGradient)"
            className="animate-pulse"
          />
          
          {/* Main logo background with 3D depth */}
          <rect
            x="6"
            y="6"
            width="88"
            height="88"
            rx="18"
            ry="18"
            fill="rgba(15, 20, 25, 0.9)"
            stroke="url(#logoGradient)"
            strokeWidth="2"
            filter="url(#glow)"
            style={{
              boxShadow: 'inset 0 2px 4px rgba(255, 255, 255, 0.1)'
            }}
          />
          
          {/* Inner accent with 3D highlight */}
          <rect
            x="10"
            y="10"
            width="80"
            height="80"
            rx="14"
            ry="14"
            fill="none"
            stroke="url(#logoGradient)"
            strokeWidth="1"
            opacity="0.4"
          />
          
          {/* Modern "P" for PROOF with 3D effect */}
          <g transform="translate(26, 25)">
            <path
              d="M8 8 L8 44 M8 8 L32 8 Q42 8 42 18 Q42 28 32 28 L8 28"
              stroke="url(#logoGradient)"
              strokeWidth="7"
              strokeLinecap="round"
              strokeLinejoin="round"
              fill="none"
              filter="url(#glow)"
            />
            {/* 3D highlight on the P */}
            <path
              d="M8 8 L8 44 M8 8 L32 8 Q42 8 42 18 Q42 28 32 28 L8 28"
              stroke="rgba(255, 255, 255, 0.3)"
              strokeWidth="2"
              strokeLinecap="round"
              strokeLinejoin="round"
              fill="none"
            />
            <circle
              cx="36"
              cy="18"
              r="4"
              fill="url(#logoGradient)"
              filter="url(#glow)"
            />
          </g>
          
          {/* 3D accent dot with glow */}
          <circle
            cx="78"
            cy="22"
            r="5"
            fill="url(#logoGradient)"
            filter="url(#glow)"
            className="animate-pulse"
          />
        </svg>
      </div>
      
      {/* PROOF Text with 3D styling */}
      {showText && (
        <span 
          className="ml-3 font-bold bg-gradient-to-r from-emerald-400 to-emerald-300 bg-clip-text text-transparent tracking-wide"
          style={{ 
            fontSize: textHeight,
            textShadow: '0 2px 4px rgba(16, 185, 129, 0.3)'
          }}
        >
          PROOF
        </span>
      )}
    </div>
  );
};

export default Logo;
